@@ -613,7 +613,7 @@ merge_changes(struct change_params *dest, const struct change_params *src)
   }
 }
 
-static show_params(const struct change_params *cp)
+static void show_params(const struct change_params *cp)
 {
   printf("Version: %d\n", cp->version);
   printf("Compatible: %d\n", cp->compat_version);
@@ -687,7 +687,7 @@ static size_t
 do_io(io_func *fn, const struct file_desc *dsc, int fd, size_t min_size)
 {
   int res;
-  int done=0;
+  size_t done=0;
   while(done<BUFFER_SIZE)
   {
     res=fn(fd, dsc->data, BUFFER_SIZE-done);
@@ -763,10 +763,8 @@ read_file(struct file_desc *dsc)
 static void
 install_mbr(struct data *dp)
 {
-  ui8_t *code, *params;
   struct change_params new_params;
   int mbr_fd = -1;
-  size_t mbr_size;
   ui8_t mbr_in[BUFFER_SIZE];
   ui8_t mbr_out[BUFFER_SIZE];
   struct file_desc target_orig={mbr_in, dp->target.path, 0};
@@ -1353,7 +1351,7 @@ parse_options(struct data *my_data, int argc, char *argv[])
       to_do=1;
       if(optarg[0]==0 || optarg[1]!=0)
       {
-	fprintf(stderr, "%s: Invalid partition number: %d\n",
+	fprintf(stderr, "%s: Invalid partition number: %s\n",
 		prog_name, optarg);
 	exit(1);
       }
